
tradeCalc <- function(ep, sl, rc=2000, risk=c(0.05, 0.03, 0.015, 0.01), reward=3) {
# ep : entry price
# sl : stop loss
# rc : risk capital (account balance or part there-of)
# risk : the risk level (or levels) you want to consider (percentage as a decimal value e.g. 5% = 0.05).
# reward : the reward multiplier.

    pipRisk <- abs(ep - sl) * 10000
    dollarRisk <- rc * risk
    dpRisk <- dollarRisk / pipRisk
    lotSize <- dpRisk / 10
    
    structure (
        list(ep=ep, 
             sl=sl, 
             tp=ep + abs(ep - sl) * reward * ifelse(ep<=sl, -1, 1),
             lotSize=dpRisk / 10, dollarRisk=dollarRisk, risk=risk
        ),
        class="tradeCalc"
    )
}


print.tradeCalc <- function(x,...) {
    cat(  "Entry:  ", sprintf("%3.5f", x$ep), 
        "\nStop:   ", sprintf("%3.5f", x$sl), " (" , sprintf("%3.1f", abs(x$ep - x$sl) * 10000), " pips)",
        "\nTarget: ", sprintf("%3.5f", x$tp), " (" , sprintf("%3.1f", abs(x$ep - x$tp) * 10000), " pips)",
        "\nLot size by risk level:\n", sep="")

    labels <- "\t"
    values <- "\t"

    for (i in 1:length(x$risk)) {
        labels <- sprintf("%s %5.2f%%", labels, x$risk[i] * 100)
        values <- sprintf("%s %5.2f ", values, x$lotSize[i])
    }
    cat(labels, '\n', values, '\n', sep='')
}

# long example
x <- tradeCalc(1.2510, 1.2505)
x


# short example
y <- tradeCalc(1.2510, 1.2515)
y